==> plantuml-gplv2-1.2022.5.tar.gz: src/net/sourceforge/plantuml/xmi/XmiSequenceDiagram.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.xmi;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import net.sourceforge.plantuml.cucadiagram.Display;
import net.sourceforge.plantuml.sequencediagram.SequenceDiagram;

public abstract class XmiSequenceDiagram {

	protected final SequenceDiagram diagram;

	public abstract void build();

	protected final Document document;

	public XmiSequenceDiagram(SequenceDiagram diagram, Document document) {
		super();
		this.diagram = diagram;
		this.document = document;
	}

	protected Element createElement(String tag, String[][] attributes) {
		return setAttributes(document.createElement(tag), attributes);
	}
	
	protected Element setAttribute(Element element, String name, String value) {
		element.setAttribute(name, value);
		return element;
	}

	protected Element setAttributes(Element element, String[][] attributes) {
		for (String[] attr : attributes) {
			element.setAttribute(attr[0], attr[1]);
		}
		return element;
	}
	
	protected String getDisplayString(Display display) {
		return String.join("\n", display.asList());
	}

	protected String getXmiId(String tag, Object object) {
		return Integer.toHexString(tag.hashCode()) + "_" + Integer.toHexString(object.hashCode());
	}
}

==> plantuml-gplv2-1.2023.5.tar.gz: src/net/sourceforge/plantuml/xmi/XmiSequenceDiagram.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.xmi;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import net.sourceforge.plantuml.klimt.creole.Display;
import net.sourceforge.plantuml.sequencediagram.SequenceDiagram;

public abstract class XmiSequenceDiagram {
    // ::remove folder when __HAXE__

	protected final SequenceDiagram diagram;

	public abstract void build();

	protected final Document document;

	public XmiSequenceDiagram(SequenceDiagram diagram, Document document) {
		super();
		this.diagram = diagram;
		this.document = document;
	}

	protected Element createElement(String tag, String[][] attributes) {
		return setAttributes(document.createElement(tag), attributes);
	}

	protected Element setAttribute(Element element, String name, String value) {
		element.setAttribute(name, value);
		return element;
	}

	protected Element setAttributes(Element element, String[][] attributes) {
		for (String[] attr : attributes) {
			element.setAttribute(attr[0], attr[1]);
		}
		return element;
	}

	protected String getDisplayString(Display display) {
		return String.join("\n", display.asList());
	}

	protected String getXmiId(String tag, Object object) {
		return Integer.toHexString(tag.hashCode()) + "_" + Integer.toHexString(object.hashCode());
	}
}
